# uwgds
### I-Tung Chen, Ameya Velankar (Mo Li Group, UW)

This Python package based on GDSFactory allows easier and faster creation of optomechanical and integrated photonics designs. With uwgds, you can easily create parameter sweep arrays using the variety of premade components to more efficiently create your GDSII.

## Installation

To install omgds.py, simply run the following command:

```bash
pip install uwgds
```

## Contributing

We welcome contributions from the community! If you have any ideas, bug reports, or feature requests, please open an issue or submit a pull request.

## License

omgds_py is licensed under the MIT License. See the License file for more information.